%% Options Test
%

clear
clc



%% Settings

% Physical parameters
Phys.LqdusInf  = 0.95; %17/17.7; % 0.8;
Phys.Stefan    = 5; %0;
Phys.Biot      = inf; % Finite Biot number not supported

% Computational parameters
Comp.DomainDepth = 15;
Comp.NGrid       = [59,39];

% Misc
LqdusGradVec = 0.05*0.95*10.^(0);
WaveVec      = 10.^(-0.5:0.01:3);


%% Main code

% Prepare results containers
GrowthRate = NaN(1,length(LqdusGradVec));
BaseGrid   = NaN(Comp.NGrid*[1;1]+1,length(LqdusGradVec));
BaseTemp   = NaN(Comp.NGrid*[1;1]+1,length(LqdusGradVec));
BaseLqdF   = NaN(Comp.NGrid*[1;1]+1,length(LqdusGradVec));
CritRayl   = NaN(1,length(LqdusGradVec));
CritWave   = NaN(1,length(LqdusGradVec));


% Loop over liquidus gradient values
for iLg = 1:length(LqdusGradVec)
    
    % Text output
    disp(['Calculation #',num2str(iLg)])
    
    % Prepare parallel containers
    PAR_CritRayl   = NaN(1,1);
    PAR_CritWave   = NaN(1,1);
    
    % Get diffusive solidification result
    IntPosFcn = @(Pos) Phys.LqdusInf - erf(Pos/2); %#ok<PFBNS>
    IG = [fzero(IntPosFcn,1); 1/sqrt(pi); 1/(1+Phys.LqdusInf/LqdusGradVec(iLg))];
    [GrowthRate(iLg),tmp_Prof,PAR_Grid] = DiffGrow_Mushy_Cond_NS(Phys.Stefan,LqdusGradVec(iLg),Phys.LqdusInf,Comp,IG);
    PAR_Temp = tmp_Prof(:,2);
    PAR_LqdF = tmp_Prof(:,5);
    
    % Loop over option sets
    for iSe = 1
        
        % Prepare stability calculation
        StabPhys       = Phys;
        StabPhys.Depth = GrowthRate(iLg);
    
        % Temperature option
        StabPhys.Temp = PAR_Temp(1:Comp.NGrid(1)+1);
        
        % Velocity boundary condition
        StabPhys.BCs = {'UZV','LZV'}; % Thermal
        StabPhys.BCs = [StabPhys.BCs,{'UZV','LZG'}]; % Stream function
        
        % Porosity profile
        StabPhys.LqdFrac = PAR_LqdF(1:Comp.NGrid(1)+1);
        
        %%%
        StabPhys.LqdusGrad = LqdusGradVec(iLg);
        %%%
        
        % Calculate results
        [PAR_CritRayl(iSe),PAR_CritWave(iSe),~,Pert,Grid] = StabilitySnapshot(InitialiseModel('PQ1'),StabPhys,Comp.NGrid(1),WaveVec);
        PertGrid(:,iLg,iSe) = Grid;
        PertTemp(:,iLg,iSe) = Pert(:,1);
        PertStrm(:,iLg,iSe) = Pert(:,2);
    end
    
    % Output parallel results
    BaseGrid(:,iLg) = PAR_Grid;
    BaseTemp(:,iLg) = PAR_Temp;
    BaseLqdF(:,iLg) = PAR_LqdF;
    CritRayl(:,iLg) = PAR_CritRayl;
    CritWave(:,iLg) = PAR_CritWave;
end


% Tidy
clear iLg PAR_CritRayl PAR_CritWave PAR_OnsetRayl IntPosFcn tmp_Prof iSe StabPhys Pert Grid


%% Output
FC = 0;
LW = 3;
FS = 18;
%FW = 'bold';
FW = 'normal';

% Convection graphs
if 1
    
    % Create window
    FC = FC+1;
    figure(FC)
    clf
    
    % Options
    PSFrag = true;
    PSFrag = false;
    %SampleIdx = [3,2,1];
    SampleIdx = [1];
    XScale = 1.5;
    ColourMax = 3;
    StrmContours = [0.02,0.05,0.1,0.2,0.3];
    
    % Loop over things
    for Samp = 1:length(SampleIdx)
        
        % Create axes
        subplot(length(SampleIdx),4,4*(Samp-1)+(2:4))
        %disp(max(max(abs(PertTemp(1:Comp.NGrid(1)+1,SampleIdx(Samp),1)))))
        
        % Create graph
        XAxis = (-500:500)/500*XScale;
        hold on
        %axes equal
        
        contourf(XAxis,BaseGrid(1:Comp.NGrid(1)+1,SampleIdx(Samp))/GrowthRate(SampleIdx(Samp)),...
            PertTemp(1:Comp.NGrid(1)+1,SampleIdx(Samp),1)*cos(CritWave(1,SampleIdx(Samp))*XAxis*GrowthRate(SampleIdx(Samp)))*100,50,'edgecolor','none')
        colormap(flipud(cbrewer('div','RdYlBu',50)))
        contour( XAxis,BaseGrid(1:Comp.NGrid(1)+1,SampleIdx(Samp))/GrowthRate(SampleIdx(Samp)),...
            PertStrm(1:Comp.NGrid(1)+1,SampleIdx(Samp),1)*sin(CritWave(1,SampleIdx(Samp))*XAxis*GrowthRate(SampleIdx(Samp))),StrmContours,'edgecolor','k','linewidth',LW)
        contour( XAxis,BaseGrid(1:Comp.NGrid(1)+1,SampleIdx(Samp))/GrowthRate(SampleIdx(Samp)),...
            PertStrm(1:Comp.NGrid(1)+1,SampleIdx(Samp),1)*sin(CritWave(1,SampleIdx(Samp))*XAxis*GrowthRate(SampleIdx(Samp))),-StrmContours,'edgecolor',[0.5,0.5,0.5],'linewidth',LW)
        h(1) = plot([0,1],-1*[1,1],'color',0.0*[1,1,1],'linewidth',LW);
        h(2) = plot([0,1],-1*[1,1],'color',0.5*[1,1,1],'linewidth',LW);
        
        %text(-1.7,0.0,'(b)')
        hold off
        pbaspect([3 1 1])
        
        if ~PSFrag
           % title(sprintf('\\Lambda = %1.2f',LqdusGradVec(SampleIdx(Samp))),'fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                xlabel('Horizontal position,  $x/\sqrt{\kappa t_c}$','fontsize',FS,'fontweight',FW,'Interpreter','latex')
            end
            set(gca,'xtick',-2:0.5:2)
            set(gca,'ydir','reverse','ylim',[0,1],'ytick',[])
            set(gca,'fontsize',FS,'fontweight',FW)
            caxis(ColourMax*[-1,1])
            ylabel(...
                colorbar('ytick',-4:2:4,'fontsize',FS,'fontweight',FW),...
                'Thermal pert.,  \theta'' x10^{-2} ','fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                legend(h,'Clockwise cell','Anti-clockwise cell')
                ans = PertStrm(1:Comp.NGrid(1)+1,SampleIdx(Samp),1);
            end
            box on
        else
            title(sprintf([num2str(Samp),'TITLE']),'fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                xlabel('RXLAB','fontsize',FS,'fontweight',FW)
            end
            set(gca,'xtick',-1.5:0.5:1.5,'xticklabel',{'RX1','RX2','RX3','RX4','RX5','RX6','RX7','RX8','RX9'})
            set(gca,'ydir','reverse','ylim',[0,1],'ytick',[])
            set(gca,'fontsize',FS,'fontweight',FW)
            caxis(ColourMax*[-1,1])
            ylabel(...
                colorbar('ytick',-3:1.5:3,'yticklabel',{'C1','C2','C3','C4','C5'},'fontsize',FS,'fontweight',FW),...
                'CLAB','fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                legend(h,'RLEG11111111','RLEG2')
                ans = PertStrm(1:Comp.NGrid(1)+1,SampleIdx(Samp),1);
            end
            box on
        end
        
        
        % Create axes
        subplot(length(SampleIdx),4,4*(Samp-1)+1)
        hold all
        plot(BaseLqdF(1:Comp.NGrid(1)+1,SampleIdx(Samp)).^1,BaseGrid(1:Comp.NGrid(1)+1,SampleIdx(Samp))/GrowthRate(SampleIdx(Samp)),'linewidth',LW)
        plot(BaseLqdF(1:Comp.NGrid(1)+1,SampleIdx(Samp)).^3,BaseGrid(1:Comp.NGrid(1)+1,SampleIdx(Samp))/GrowthRate(SampleIdx(Samp)),'linewidth',LW)
        % text(-0.3,0.0,'(a)')
        
        hold off
        if ~PSFrag
            if Samp == length(SampleIdx)
                xlabel('Value,  $\chi$ or $\Pi$','fontsize',FS,'fontweight',FW,'Interpreter','latex')
            end
            set(gca,'xlim',[0,1])
            ylabel('Depth, $\eta =z/h(t_c)$','fontsize',FS,'fontweight',FW,'Interpreter','latex')
            set(gca,'ydir','reverse','ylim',[0,1],'ytick',0:0.5:1.0)
            set(gca,'fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                legend('Liquid fraction,  \chi','Permeability,  \Pi','location','northeast')
            end
        else
            if Samp == length(SampleIdx)
                xlabel('LXLAB','fontsize',FS,'fontweight',FW)
            end
            set(gca,'xlim',[0,1],'xtick',0:0.5:1,'xticklabel',{'LX1','LX2','LX3'})
            ylabel('YLAB','fontsize',FS,'fontweight',FW)
            set(gca,'ydir','reverse','ylim',[0,1],'ytick',0:0.25:1,'yticklabel',{'Y1','Y2','Y3','Y4','Y5'})
            set(gca,'fontsize',FS,'fontweight',FW)
            if Samp == length(SampleIdx)
                legend('LLEG11111111','LLEG2','location','northwest')
            end
        end
        box on
    end
    
    % Tidy
    clear SampleIdx XScale ColourMax StrmContours Samp XAxis h
end

% Tidy
clear FC LW FS FW


