function [X,Y] = FindStationaryPoint(x,y,MinMax)
% This function finds the minimum or maximum of the curve y(x) using a
% simple quadratic interpolation.
%
% Inputs:  x      - x data set
%          y      - y data set
%          MinMax - Minimum/Maximum flag
%                     1 = Maximum
%                     0 = Minimum
%
% Outputs: X - x value at stationary point
%          Y - y value at stationary point
%
% CoreFunctions Version 1.1
% (20/02/15)

    % Find Maximum
    if MinMax
        Ind = find(y == max(y)) + [-1,0,1];
    
    % Find Minimum
    else
        Ind = find(y == min(y)) + [-1,0,1];
    end
    
    % Locate SP
    try
        Coeff = polyfit(x(Ind),y(Ind),2);
        X = -Coeff(2)/(2*Coeff(1));
        Y = Coeff(1)*X^2 + Coeff(2)*X + Coeff(3);
    catch
        X = NaN;
        Y = NaN;
    end
end